import process from "process";
import fs from "fs-extra";
import path from "path";
import sharp from "sharp";

const args_ss = process.argv.slice(2);
const task_as: Promise<number>[] = [];
const texture_format_ss = [
	"jpg",
	"png",
	"bmp",
	"tga",
	"hdr",
	"webp",
	"psd",
	"tiff",
];

let traverse_dir_f = (url_s_: string) => {
	// 文件夹
	if (fs.statSync(url_s_).isDirectory()) {
		fs.readdirSync(url_s_).forEach((v_s) => {
			traverse_dir_f(path.join(url_s_, v_s));
		});
	}
	// 图片
	else if (
		texture_format_ss.includes(path.extname(url_s_).slice(1).toLowerCase())
	) {
		task_as.push(
			new Promise<number>((resolve_f) => {
				sharp(url_s_)
					.metadata()
					.then((v): void => {
						if (!v.depth || !v.channels || !v.width || !v.height) {
							console.error("读取错误", url_s_);
							resolve_f(0);
							return;
						}

						let bit_depth_n =
							{
								uchar: 1,
								char: 1,
								ushort: 2,
								short: 2,
								uint: 4,
								int: 4,
								float: 4,
								complex: 8,
								double: 8,
								dpcomplex: 16,
							}[v.depth]! * v.channels;

						let mb_size_n = (v.width * v.height * bit_depth_n) / 1024 / 1024;

						resolve_f(mb_size_n);
					});
			})
		);
	}
};

traverse_dir_f(path.resolve(args_ss[0]));

Promise.all(task_as).then((v_ns) => {
	console.log("总大小：", v_ns.reduce((pre, curr) => pre + curr, 0).toFixed(2));
});
